# coding: utf-8

"""
    Ringer Business API

    This API provides comprehensive endpoints for the Ringer Business system. It includes functionality for managing customer accounts, addresses, sites,  phone numbers, payments, users, and other business resources.  Operations typically require authentication and appropriate permissions. 

    The version of the OpenAPI document: 1.0.4
    Contact: support@ringer.tel
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class LocationUpdateRequest(BaseModel):
    """
    Data for updating an existing location. All fields are typically resubmitted for a PUT.
    """ # noqa: E501
    name: StrictStr = Field(description="A user-friendly name for this location (e.g., \"Main Building\", \"Floor 2 Office\").")
    house_number: StrictStr = Field(description="The street number of the address.")
    house_number_suffix: Optional[StrictStr] = Field(default=None, description="Suffix for the street number, if any (e.g., \"A\", \"1/2\").")
    street: StrictStr = Field(description="The street name.")
    city: StrictStr = Field(description="The city name.")
    state_province: StrictStr = Field(description="The state or province code (e.g., \"CO\", \"ON\").")
    postal_code: StrictStr = Field(description="The postal or ZIP code.")
    country_code: StrictStr = Field(description="Two-letter ISO 3166-1 alpha-2 country code.")
    caller_id_name: Optional[StrictStr] = Field(default=None, description="Caller ID name to be used for E911 calls originating from this location.")
    e911_enabled: Optional[StrictBool] = Field(default=True, description="Indicates if E911 service is enabled for this location. Geocoding and validation occur upon setting this.")
    __properties: ClassVar[List[str]] = ["name", "house_number", "house_number_suffix", "street", "city", "state_province", "postal_code", "country_code", "caller_id_name", "e911_enabled"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of LocationUpdateRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if house_number_suffix (nullable) is None
        # and model_fields_set contains the field
        if self.house_number_suffix is None and "house_number_suffix" in self.model_fields_set:
            _dict['house_number_suffix'] = None

        # set to None if caller_id_name (nullable) is None
        # and model_fields_set contains the field
        if self.caller_id_name is None and "caller_id_name" in self.model_fields_set:
            _dict['caller_id_name'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of LocationUpdateRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "name": obj.get("name"),
            "house_number": obj.get("house_number"),
            "house_number_suffix": obj.get("house_number_suffix"),
            "street": obj.get("street"),
            "city": obj.get("city"),
            "state_province": obj.get("state_province"),
            "postal_code": obj.get("postal_code"),
            "country_code": obj.get("country_code"),
            "caller_id_name": obj.get("caller_id_name"),
            "e911_enabled": obj.get("e911_enabled") if obj.get("e911_enabled") is not None else True
        })
        return _obj


