# coding: utf-8

"""
    Ringer Business API

    This API provides comprehensive endpoints for the Ringer Business system. It includes functionality for managing customer accounts, addresses, sites,  phone numbers, payments, users, and other business resources.  Operations typically require authentication and appropriate permissions. 

    The version of the OpenAPI document: 1.0.4
    Contact: support@ringer.tel
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from ringer_business.models.e911_list_response import E911ListResponse

class TestE911ListResponse(unittest.TestCase):
    """E911ListResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> E911ListResponse:
        """Test E911ListResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `E911ListResponse`
        """
        model = E911ListResponse()
        if include_optional:
            return E911ListResponse(
                e911_records = [
                    {"id":19,"site_id":6,"name":"Main Office E911","caller_id_name":"Teliax Office Emergency","house_number":"2150","house_number_suffix":"Ste 310","street":"West 29th Ave","city":"Denver","state_province":"CO","postal_code":"80211","country_code":"US","validated":true,"did_number":"+13035550123","links":[{"href":"/sites/6/e911s/19","rel":"self","method":"GET"}]}
                    ]
            )
        else:
            return E911ListResponse(
                e911_records = [
                    {"id":19,"site_id":6,"name":"Main Office E911","caller_id_name":"Teliax Office Emergency","house_number":"2150","house_number_suffix":"Ste 310","street":"West 29th Ave","city":"Denver","state_province":"CO","postal_code":"80211","country_code":"US","validated":true,"did_number":"+13035550123","links":[{"href":"/sites/6/e911s/19","rel":"self","method":"GET"}]}
                    ],
        )
        """

    def testE911ListResponse(self):
        """Test E911ListResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
