# coding: utf-8

"""
    Ringer Business API - Statements

    This API provides endpoints for accessing account statements (receipts). Statements are typically generated at the end of a service interval and provide a summary of charges and payments. Developers can use this API to retrieve a list of statements or the details of a specific statement. 

    The version of the OpenAPI document: 1.0.0
    Contact: support@ringer.tel
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from ringer_business.models.statement_list_response import StatementListResponse

class TestStatementListResponse(unittest.TestCase):
    """StatementListResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> StatementListResponse:
        """Test StatementListResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `StatementListResponse`
        """
        model = StatementListResponse()
        if include_optional:
            return StatementListResponse(
                statements = [
                    {"id":501,"statement_number":"STMT-2023-10-001","period_start":"2023-10-01T00:00:00Z","period_end":"2023-10-31T23:59:59Z","issue_date":"2023-11-01T00:00:00Z","due_date":"2023-11-15T00:00:00Z","total_amount":"150.75","currency":"USD","status":"paid","created_at_original":"02/02/2018","closed_at_original":"02/02/2018","image_url":"https://cdn.example.com/statements/stmt_501.png","pdf_url":"https://cdn.example.com/statements/stmt_501.pdf","cdr_export_url":"https://cdn.example.com/reports/cdr_stmt_501.csv","links":[{"href":"/statements/501","rel":"self","method":"GET"}]}
                    ],
                total_items = 120,
                total_pages = 5,
                current_page = 1,
                per_page = 25,
                links = [
                    ringer_business.models.link.Link(
                        href = '', 
                        rel = '', 
                        title = '', 
                        method = 'GET', )
                    ]
            )
        else:
            return StatementListResponse(
                statements = [
                    {"id":501,"statement_number":"STMT-2023-10-001","period_start":"2023-10-01T00:00:00Z","period_end":"2023-10-31T23:59:59Z","issue_date":"2023-11-01T00:00:00Z","due_date":"2023-11-15T00:00:00Z","total_amount":"150.75","currency":"USD","status":"paid","created_at_original":"02/02/2018","closed_at_original":"02/02/2018","image_url":"https://cdn.example.com/statements/stmt_501.png","pdf_url":"https://cdn.example.com/statements/stmt_501.pdf","cdr_export_url":"https://cdn.example.com/reports/cdr_stmt_501.csv","links":[{"href":"/statements/501","rel":"self","method":"GET"}]}
                    ],
                total_items = 120,
                total_pages = 5,
                current_page = 1,
                per_page = 25,
        )
        """

    def testStatementListResponse(self):
        """Test StatementListResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
