# coding: utf-8

"""
    Ringer Business API

    This API provides comprehensive endpoints for the Ringer Business system. It includes functionality for managing customer accounts, addresses, sites,  phone numbers, payments, users, and other business resources.  Operations typically require authentication and appropriate permissions. 

    The version of the OpenAPI document: 1.0.4
    Contact: support@ringer.tel
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from ringer_business.api.site_features_forwards_api import SiteFeaturesForwardsApi


class TestSiteFeaturesForwardsApi(unittest.TestCase):
    """SiteFeaturesForwardsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = SiteFeaturesForwardsApi()

    def tearDown(self) -> None:
        pass

    def test_create_site_forward(self) -> None:
        """Test case for create_site_forward

        Create Forward for a Site
        """
        pass

    def test_delete_site_forward_by_id(self) -> None:
        """Test case for delete_site_forward_by_id

        Delete Site Forward
        """
        pass

    def test_get_site_forward_by_id(self) -> None:
        """Test case for get_site_forward_by_id

        Get Site Forward Details
        """
        pass

    def test_list_site_available_forwards(self) -> None:
        """Test case for list_site_available_forwards

        List Available Forwards for a Site/User
        """
        pass

    def test_list_site_forwards(self) -> None:
        """Test case for list_site_forwards

        List Forwards for a Site
        """
        pass

    def test_transfer_site_forward(self) -> None:
        """Test case for transfer_site_forward

        Transfer Site Forward
        """
        pass

    def test_update_site_forward_by_id(self) -> None:
        """Test case for update_site_forward_by_id

        Update Site Forward
        """
        pass


if __name__ == '__main__':
    unittest.main()
