# coding: utf-8

"""
    Ringer Business API

    This API provides comprehensive endpoints for the Ringer Business system. It includes functionality for managing customer accounts, addresses, sites,  phone numbers, payments, users, and other business resources.  Operations typically require authentication and appropriate permissions. 

    The version of the OpenAPI document: 1.0.4
    Contact: support@ringer.tel
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from ringer_business.models.schedule_update_request_data_attributes import ScheduleUpdateRequestDataAttributes

class TestScheduleUpdateRequestDataAttributes(unittest.TestCase):
    """ScheduleUpdateRequestDataAttributes unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ScheduleUpdateRequestDataAttributes:
        """Test ScheduleUpdateRequestDataAttributes
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ScheduleUpdateRequestDataAttributes`
        """
        model = ScheduleUpdateRequestDataAttributes()
        if include_optional:
            return ScheduleUpdateRequestDataAttributes(
                name = '',
                time_zone = '',
                start_hour = '',
                start_minute = '',
                end_hour = '',
                end_minute = '',
                start_weekday = '',
                end_weekday = '',
                exceptions = '',
                positive_destination_code = '',
                negative_destination_code = ''
            )
        else:
            return ScheduleUpdateRequestDataAttributes(
        )
        """

    def testScheduleUpdateRequestDataAttributes(self):
        """Test ScheduleUpdateRequestDataAttributes"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
