# coding: utf-8

"""
    Ringer Business API - Timezones

    This API provides an endpoint for listing available Timezones. Timezones are crucial for configuring time-sensitive features within the phone system, such as schedules, business hours, and call logging timestamps. This endpoint allows developers to retrieve a comprehensive list of supported IANA timezone identifiers. 

    The version of the OpenAPI document: 1.0.0
    Contact: support@ringer.tel
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from ringer_business.models.timezone_list_response import TimezoneListResponse

class TestTimezoneListResponse(unittest.TestCase):
    """TimezoneListResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> TimezoneListResponse:
        """Test TimezoneListResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `TimezoneListResponse`
        """
        model = TimezoneListResponse()
        if include_optional:
            return TimezoneListResponse(
                timezones = [
                    'America/Los_Angeles'
                    ]
            )
        else:
            return TimezoneListResponse(
                timezones = [
                    'America/Los_Angeles'
                    ],
        )
        """

    def testTimezoneListResponse(self):
        """Test TimezoneListResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
