# coding: utf-8

"""
    Ringer Business API - Call Blocking Management

    This API provides endpoints for managing call blocking rules on a specific site. Call blocking allows customers to prevent inbound calls from specified numbers to certain extensions or all extensions on a site. When a blocked number attempts to call, they will typically receive a busy tone.  Functionality includes: - Listing all call block rules for a site. - Creating a new call block rule. - Retrieving details of a specific call block rule. - Updating an existing call block rule. - Deleting a call block rule. 

    The version of the OpenAPI document: 1.0.0
    Contact: support@ringer.tel
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from ringer_business.api.call_blocking_api import CallBlockingApi


class TestCallBlockingApi(unittest.TestCase):
    """CallBlockingApi unit test stubs"""

    def setUp(self) -> None:
        self.api = CallBlockingApi()

    def tearDown(self) -> None:
        pass

    def test_create_site_call_block(self) -> None:
        """Test case for create_site_call_block

        Create a New Call Block Rule
        """
        pass

    def test_delete_site_call_block_by_id(self) -> None:
        """Test case for delete_site_call_block_by_id

        Delete a Call Block Rule
        """
        pass

    def test_get_site_call_block_by_id(self) -> None:
        """Test case for get_site_call_block_by_id

        Get Call Block Rule Details
        """
        pass

    def test_list_site_call_blocks(self) -> None:
        """Test case for list_site_call_blocks

        List Call Block Rules for a Site
        """
        pass

    def test_update_site_call_block_by_id(self) -> None:
        """Test case for update_site_call_block_by_id

        Update an Existing Call Block Rule
        """
        pass


if __name__ == '__main__':
    unittest.main()
