# coding: utf-8

"""
    Ringer Business API - Thin Clients

    This API provides an endpoint for listing available Thin Clients. Thin Clients are nodes that handle call processing for Sites. When configuring a Site, a Thin Client needs to be assigned to it. This endpoint helps developers retrieve the list of available thin clients to present as options to users. 

    The version of the OpenAPI document: 1.0.0
    Contact: support@ringer.tel
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from ringer_business.api.thin_clients_api import ThinClientsApi


class TestThinClientsApi(unittest.TestCase):
    """ThinClientsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ThinClientsApi()

    def tearDown(self) -> None:
        pass

    def test_list_available_thin_clients(self) -> None:
        """Test case for list_available_thin_clients

        List Available Thin Clients
        """
        pass


if __name__ == '__main__':
    unittest.main()
