# coding: utf-8

"""
    Ringer Business API

    This API provides comprehensive endpoints for the Ringer Business system. It includes functionality for managing customer accounts, addresses, sites,  phone numbers, payments, users, and other business resources.  Operations typically require authentication and appropriate permissions. 

    The version of the OpenAPI document: 1.0.4
    Contact: support@ringer.tel
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from ringer_business.api.authentication_api import AuthenticationApi


class TestAuthenticationApi(unittest.TestCase):
    """AuthenticationApi unit test stubs"""

    def setUp(self) -> None:
        self.api = AuthenticationApi()

    def tearDown(self) -> None:
        pass

    def test_fetch_access_token(self) -> None:
        """Test case for fetch_access_token

        Obtain an OAuth 2.0 Access Token
        """
        pass

    def test_revoke_access_token(self) -> None:
        """Test case for revoke_access_token

        Revoke an OAuth 2.0 Token
        """
        pass


if __name__ == '__main__':
    unittest.main()
