# coding: utf-8

"""
    Ringer Business API - Sign Up

    This API provides the endpoint for new customers to sign up for the Ringer Business service. Successful sign-up creates a new customer account and provides a confirmation token that is typically used in a subsequent step to activate the account (see Confirmation API). 

    The version of the OpenAPI document: 1.0.0
    Contact: support@ringer.tel
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from ringer_business.models.customer_registration_response import CustomerRegistrationResponse

class TestCustomerRegistrationResponse(unittest.TestCase):
    """CustomerRegistrationResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> CustomerRegistrationResponse:
        """Test CustomerRegistrationResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `CustomerRegistrationResponse`
        """
        model = CustomerRegistrationResponse()
        if include_optional:
            return CustomerRegistrationResponse(
                id = 123,
                name = 'Example Innovations Inc.',
                active = False,
                locale = 'en',
                international_enabled = False,
                balance_preference_in_dollars = '10.00',
                recharge_preference_in_dollars = '20.00',
                address = {"id":672,"email":"contact@exampleinnovations.com","street_address":"123 Innovation Drive, Suite 400","country":"US","city":"Techville","state_province":"CA","postal_code":"90210","contact_number":"18005551212"},
                confirmation_token = 'abcdef123456ghijkl7890mnopqrst',
                links = [{"href":"/confirmation","rel":"confirmAccount","title":"Confirm Account","method":"POST"},{"href":"/account/123","rel":"self","title":"View Account Details","method":"GET"}]
            )
        else:
            return CustomerRegistrationResponse(
                id = 123,
                name = 'Example Innovations Inc.',
                active = False,
                address = {"id":672,"email":"contact@exampleinnovations.com","street_address":"123 Innovation Drive, Suite 400","country":"US","city":"Techville","state_province":"CA","postal_code":"90210","contact_number":"18005551212"},
                confirmation_token = 'abcdef123456ghijkl7890mnopqrst',
        )
        """

    def testCustomerRegistrationResponse(self):
        """Test CustomerRegistrationResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
