# coding: utf-8

"""
    Ringer Business API

    This API provides comprehensive endpoints for the Ringer Business system. It includes functionality for managing customer accounts, addresses, sites,  phone numbers, payments, users, and other business resources.  Operations typically require authentication and appropriate permissions. 

    The version of the OpenAPI document: 1.0.4
    Contact: support@ringer.tel
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from ringer_business.api.plans_api import PlansApi


class TestPlansApi(unittest.TestCase):
    """PlansApi unit test stubs"""

    def setUp(self) -> None:
        self.api = PlansApi()

    def tearDown(self) -> None:
        pass

    def test_get_plan_by_id(self) -> None:
        """Test case for get_plan_by_id

        Get Plan Details
        """
        pass

    def test_list_account_plans(self) -> None:
        """Test case for list_account_plans

        List Current Account Plan(s)
        """
        pass


if __name__ == '__main__':
    unittest.main()
