# coding: utf-8

"""
    Ringer Business API - Credit Card Management

    This API provides endpoints for managing credit card payment methods associated with a customer account. It allows developers to: - List existing credit cards. - Add a new credit card. - Retrieve details of a specific credit card. - Update information for an existing credit card. - Delete a credit card. - Verify a newly added credit card.  Proper security and PCI compliance considerations are paramount when handling credit card data. These endpoints are designed to interact with a secure payment processing backend. 

    The version of the OpenAPI document: 1.0.0
    Contact: support@ringer.tel
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from ringer_business.models.credit_card_update_request import CreditCardUpdateRequest

class TestCreditCardUpdateRequest(unittest.TestCase):
    """CreditCardUpdateRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> CreditCardUpdateRequest:
        """Test CreditCardUpdateRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `CreditCardUpdateRequest`
        """
        model = CreditCardUpdateRequest()
        if include_optional:
            return CreditCardUpdateRequest(
                name = 'Work Visa (Primary)',
                priority = 100,
                active = True
            )
        else:
            return CreditCardUpdateRequest(
        )
        """

    def testCreditCardUpdateRequest(self):
        """Test CreditCardUpdateRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
