# coding: utf-8

"""
    Ringer Business API - Sites Management

    This API provides endpoints for managing Sites within a Ringer Business account. Sites are collections of telephony features and can represent physical locations, departments, or logical groupings of phone system behaviors.  Developers can use this API to: - List all sites for an account. - Create a new site. - Retrieve details of a specific site. - Update an existing site's configuration. - Delete a site (and its associated features). - Rebuild a site's configuration with the call processing system. - List potential destinations and failovers for site features.  Site management often involves configuring various telephony features, which will be detailed in separate feature-specific API documents (e.g., devices, phone numbers, menus). 

    The version of the OpenAPI document: 1.0.0
    Contact: support@ringer.tel
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from ringer_business.api.sites_api import SitesApi


class TestSitesApi(unittest.TestCase):
    """SitesApi unit test stubs"""

    def setUp(self) -> None:
        self.api = SitesApi()

    def tearDown(self) -> None:
        pass

    def test_create_site(self) -> None:
        """Test case for create_site

        Create a New Site
        """
        pass

    def test_delete_site_by_id(self) -> None:
        """Test case for delete_site_by_id

        Delete a Site
        """
        pass

    def test_get_site_by_id(self) -> None:
        """Test case for get_site_by_id

        Get Site Details
        """
        pass

    def test_list_site_potential_destinations(self) -> None:
        """Test case for list_site_potential_destinations

        List Potential Destinations for Site Features
        """
        pass

    def test_list_site_potential_failovers(self) -> None:
        """Test case for list_site_potential_failovers

        List Potential Failover Destinations for Site Features
        """
        pass

    def test_list_sites(self) -> None:
        """Test case for list_sites

        List Sites
        """
        pass

    def test_rebuild_site_by_id(self) -> None:
        """Test case for rebuild_site_by_id

        Rebuild Site Configuration
        """
        pass

    def test_update_site_by_id(self) -> None:
        """Test case for update_site_by_id

        Update Site Configuration
        """
        pass


if __name__ == '__main__':
    unittest.main()
