# coding: utf-8

"""
    Ringer Business API

    This API provides comprehensive endpoints for the Ringer Business system. It includes functionality for managing customer accounts, addresses, sites,  phone numbers, payments, users, and other business resources.  Operations typically require authentication and appropriate permissions. 

    The version of the OpenAPI document: 1.0.4
    Contact: support@ringer.tel
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from ringer_business.api.site_features_seats_api import SiteFeaturesSeatsApi


class TestSiteFeaturesSeatsApi(unittest.TestCase):
    """SiteFeaturesSeatsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = SiteFeaturesSeatsApi()

    def tearDown(self) -> None:
        pass

    def test_create_site_seat(self) -> None:
        """Test case for create_site_seat

        Create Seat for a Site
        """
        pass

    def test_delete_site_seat_by_id(self) -> None:
        """Test case for delete_site_seat_by_id

        Delete Seat
        """
        pass

    def test_get_site_seat_by_id(self) -> None:
        """Test case for get_site_seat_by_id

        Get Seat Details
        """
        pass

    def test_list_site_seats(self) -> None:
        """Test case for list_site_seats

        List Seats for a Site
        """
        pass

    def test_transfer_site_seat(self) -> None:
        """Test case for transfer_site_seat

        Transfer Seat to Another Site
        """
        pass

    def test_update_site_seat_by_id(self) -> None:
        """Test case for update_site_seat_by_id

        Update Seat Information
        """
        pass


if __name__ == '__main__':
    unittest.main()
