# coding: utf-8

"""
    Ringer Business API

    This API provides comprehensive endpoints for the Ringer Business system. It includes functionality for managing customer accounts, addresses, sites,  phone numbers, payments, users, and other business resources.  Operations typically require authentication and appropriate permissions. 

    The version of the OpenAPI document: 1.0.4
    Contact: support@ringer.tel
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from ringer_business.api.site_features_schedules_api import SiteFeaturesSchedulesApi


class TestSiteFeaturesSchedulesApi(unittest.TestCase):
    """SiteFeaturesSchedulesApi unit test stubs"""

    def setUp(self) -> None:
        self.api = SiteFeaturesSchedulesApi()

    def tearDown(self) -> None:
        pass

    def test_create_site_schedule(self) -> None:
        """Test case for create_site_schedule

        Create Schedule for a Site
        """
        pass

    def test_delete_site_schedule_by_id(self) -> None:
        """Test case for delete_site_schedule_by_id

        Delete a Schedule
        """
        pass

    def test_get_site_schedule_by_id(self) -> None:
        """Test case for get_site_schedule_by_id

        Get Schedule Details
        """
        pass

    def test_list_site_available_schedules(self) -> None:
        """Test case for list_site_available_schedules

        List Available Schedules for a Site
        """
        pass

    def test_list_site_schedules(self) -> None:
        """Test case for list_site_schedules

        List Schedules for a Site
        """
        pass

    def test_transfer_site_schedule(self) -> None:
        """Test case for transfer_site_schedule

        Transfer Schedule to Another Site
        """
        pass

    def test_update_site_schedule_by_id(self) -> None:
        """Test case for update_site_schedule_by_id

        Update Schedule
        """
        pass


if __name__ == '__main__':
    unittest.main()
