# coding: utf-8

"""
    Ringer Business API

    This API provides comprehensive endpoints for the Ringer Business system. It includes functionality for managing customer accounts, addresses, sites,  phone numbers, payments, users, and other business resources.  Operations typically require authentication and appropriate permissions. 

    The version of the OpenAPI document: 1.0.4
    Contact: support@ringer.tel
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from ringer_business.api.accounts_api import AccountsApi


class TestAccountsApi(unittest.TestCase):
    """AccountsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = AccountsApi()

    def tearDown(self) -> None:
        pass

    def test_activate_account(self) -> None:
        """Test case for activate_account

        Activate Current Account
        """
        pass

    def test_close_account(self) -> None:
        """Test case for close_account

        Close Current Account
        """
        pass

    def test_get_account_details(self) -> None:
        """Test case for get_account_details

        Get Current Account Details
        """
        pass

    def test_update_account(self) -> None:
        """Test case for update_account

        Update Current Account Information
        """
        pass


if __name__ == '__main__':
    unittest.main()
