# coding: utf-8

"""
    Ringer Business API

    This API provides comprehensive endpoints for the Ringer Business system. It includes functionality for managing customer accounts, addresses, sites,  phone numbers, payments, users, and other business resources.  Operations typically require authentication and appropriate permissions. 

    The version of the OpenAPI document: 1.0.4
    Contact: support@ringer.tel
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from ringer_business.api.country_codes_api import CountryCodesApi


class TestCountryCodesApi(unittest.TestCase):
    """CountryCodesApi unit test stubs"""

    def setUp(self) -> None:
        self.api = CountryCodesApi()

    def tearDown(self) -> None:
        pass

    def test_list_available_country_codes(self) -> None:
        """Test case for list_available_country_codes

        List Available Country Codes
        """
        pass


if __name__ == '__main__':
    unittest.main()
