# coding: utf-8

"""
    Ringer Business API

    This API provides comprehensive endpoints for the Ringer Business system. It includes functionality for managing customer accounts, addresses, sites,  phone numbers, payments, users, and other business resources.  Operations typically require authentication and appropriate permissions. 

    The version of the OpenAPI document: 1.0.4
    Contact: support@ringer.tel
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from ringer_business.models.paginated_menu_list_response import PaginatedMenuListResponse

class TestPaginatedMenuListResponse(unittest.TestCase):
    """PaginatedMenuListResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PaginatedMenuListResponse:
        """Test PaginatedMenuListResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PaginatedMenuListResponse`
        """
        model = PaginatedMenuListResponse()
        if include_optional:
            return PaginatedMenuListResponse(
                menus = [
                    {"id":55,"site_id":6,"name":"Main Business Hours Menu","pin":"1234","fail_over_destination_code":"voicemailbox:general_vm","options":{"0":"ring_group:sales_rg","1":"extension:1001","*":"voicemailbox:operator_vm"},"greeting_url":"https://cdn.example.com/greetings/menu_55.mp3","links":[{"href":"/sites/6/menus/55","rel":"self","method":"GET"}]}
                    ],
                total_items = 20,
                total_pages = 2,
                current_page = 1,
                per_page = 10,
                links = [
                    ringer_business.models.link.Link(
                        href = '/example/resource/123', 
                        rel = 'self', 
                        method = 'GET', 
                        title = 'View Example Resource', )
                    ]
            )
        else:
            return PaginatedMenuListResponse(
                menus = [
                    {"id":55,"site_id":6,"name":"Main Business Hours Menu","pin":"1234","fail_over_destination_code":"voicemailbox:general_vm","options":{"0":"ring_group:sales_rg","1":"extension:1001","*":"voicemailbox:operator_vm"},"greeting_url":"https://cdn.example.com/greetings/menu_55.mp3","links":[{"href":"/sites/6/menus/55","rel":"self","method":"GET"}]}
                    ],
                total_items = 20,
                total_pages = 2,
                current_page = 1,
                per_page = 10,
        )
        """

    def testPaginatedMenuListResponse(self):
        """Test PaginatedMenuListResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
