# coding: utf-8

"""
    Ringer Business API

    This API provides comprehensive endpoints for the Ringer Business system. It includes functionality for managing customer accounts, addresses, sites,  phone numbers, payments, users, and other business resources.  Operations typically require authentication and appropriate permissions. 

    The version of the OpenAPI document: 1.0.4
    Contact: support@ringer.tel
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from ringer_business.api.site_features_devices_api import SiteFeaturesDevicesApi


class TestSiteFeaturesDevicesApi(unittest.TestCase):
    """SiteFeaturesDevicesApi unit test stubs"""

    def setUp(self) -> None:
        self.api = SiteFeaturesDevicesApi()

    def tearDown(self) -> None:
        pass

    def test_create_site_device(self) -> None:
        """Test case for create_site_device

        Create a Device for a Site
        """
        pass

    def test_delete_site_device_by_id(self) -> None:
        """Test case for delete_site_device_by_id

        Delete a Device
        """
        pass

    def test_get_site_device_by_id(self) -> None:
        """Test case for get_site_device_by_id

        Get Device Details
        """
        pass

    def test_list_site_available_devices(self) -> None:
        """Test case for list_site_available_devices

        List Available Devices for a Site/User
        """
        pass

    def test_list_site_devices(self) -> None:
        """Test case for list_site_devices

        List Devices for a Site
        """
        pass

    def test_regenerate_site_device_password(self) -> None:
        """Test case for regenerate_site_device_password

        Regenerate Device SIP Password
        """
        pass

    def test_transfer_device_to_new_site(self) -> None:
        """Test case for transfer_device_to_new_site

        Transfer Device to Another Site
        """
        pass

    def test_update_site_device_by_id(self) -> None:
        """Test case for update_site_device_by_id

        Update Device Configuration
        """
        pass


if __name__ == '__main__':
    unittest.main()
