# coding: utf-8

"""
    Ringer Business API

    This API provides comprehensive endpoints for the Ringer Business system. It includes functionality for managing customer accounts, addresses, sites,  phone numbers, payments, users, and other business resources.  Operations typically require authentication and appropriate permissions. 

    The version of the OpenAPI document: 1.0.4
    Contact: support@ringer.tel
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from ringer_business.api.site_features_e911_api import SiteFeaturesE911Api


class TestSiteFeaturesE911Api(unittest.TestCase):
    """SiteFeaturesE911Api unit test stubs"""

    def setUp(self) -> None:
        self.api = SiteFeaturesE911Api()

    def tearDown(self) -> None:
        pass

    def test_delete_site_e911_record_by_id(self) -> None:
        """Test case for delete_site_e911_record_by_id

        Delete E911 Record
        """
        pass

    def test_get_site_e911_record_by_id(self) -> None:
        """Test case for get_site_e911_record_by_id

        Get E911 Record Details
        """
        pass

    def test_list_site_e911_records(self) -> None:
        """Test case for list_site_e911_records

        List E911 Records for a Site
        """
        pass

    def test_update_site_e911_record_by_id(self) -> None:
        """Test case for update_site_e911_record_by_id

        Update E911 Record
        """
        pass


if __name__ == '__main__':
    unittest.main()
