# coding: utf-8

"""
    Ringer Business API

    This API provides comprehensive endpoints for the Ringer Business system. It includes functionality for managing customer accounts, addresses, sites,  phone numbers, payments, users, and other business resources.  Operations typically require authentication and appropriate permissions. 

    The version of the OpenAPI document: 1.0.4
    Contact: support@ringer.tel
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from ringer_business.api.site_features_locations_api import SiteFeaturesLocationsApi


class TestSiteFeaturesLocationsApi(unittest.TestCase):
    """SiteFeaturesLocationsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = SiteFeaturesLocationsApi()

    def tearDown(self) -> None:
        pass

    def test_create_site_location(self) -> None:
        """Test case for create_site_location

        Create a Location for a Site
        """
        pass

    def test_delete_site_location_by_id(self) -> None:
        """Test case for delete_site_location_by_id

        Delete a Location
        """
        pass

    def test_get_site_location_by_id(self) -> None:
        """Test case for get_site_location_by_id

        Get Location Details
        """
        pass

    def test_list_site_locations(self) -> None:
        """Test case for list_site_locations

        List Locations for a Site
        """
        pass

    def test_update_site_location_by_id(self) -> None:
        """Test case for update_site_location_by_id

        Update Location Details
        """
        pass


if __name__ == '__main__':
    unittest.main()
