# coding: utf-8

"""
    Ringer Business API

    This API provides comprehensive endpoints for the Ringer Business system. It includes functionality for managing customer accounts, addresses, sites,  phone numbers, payments, users, and other business resources.  Operations typically require authentication and appropriate permissions. 

    The version of the OpenAPI document: 1.0.4
    Contact: support@ringer.tel
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from ringer_business.models.e911_response import E911Response

class TestE911Response(unittest.TestCase):
    """E911Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> E911Response:
        """Test E911Response
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `E911Response`
        """
        model = E911Response()
        if include_optional:
            return E911Response(
                name = 'Headquarters - Main Lobby E911',
                caller_id_name = 'Innovatech Solutions - Lobby',
                house_number = '2150',
                house_number_suffix = 'Suite 100',
                street = 'West 29th Avenue',
                city = 'Denver',
                state_province = 'CO',
                postal_code = '80211',
                country_code = 'US',
                id = 19,
                site_id = 6,
                validated = True,
                did_number = '+13035550100',
                links = [
                    ringer_business.models.link.Link(
                        href = '/example/resource/123', 
                        rel = 'self', 
                        method = 'GET', 
                        title = 'View Example Resource', )
                    ]
            )
        else:
            return E911Response(
                name = 'Headquarters - Main Lobby E911',
                caller_id_name = 'Innovatech Solutions - Lobby',
                house_number = '2150',
                street = 'West 29th Avenue',
                city = 'Denver',
                state_province = 'CO',
                postal_code = '80211',
                country_code = 'US',
                id = 19,
                site_id = 6,
                validated = True,
        )
        """

    def testE911Response(self):
        """Test E911Response"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
