# coding: utf-8

"""
    Ringer Business API - Timezones

    This API provides an endpoint for listing available Timezones. Timezones are crucial for configuring time-sensitive features within the phone system, such as schedules, business hours, and call logging timestamps. This endpoint allows developers to retrieve a comprehensive list of supported IANA timezone identifiers. 

    The version of the OpenAPI document: 1.0.0
    Contact: support@ringer.tel
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from ringer_business.api.timezones_api import TimezonesApi


class TestTimezonesApi(unittest.TestCase):
    """TimezonesApi unit test stubs"""

    def setUp(self) -> None:
        self.api = TimezonesApi()

    def tearDown(self) -> None:
        pass

    def test_list_available_timezones(self) -> None:
        """Test case for list_available_timezones

        List Available Timezones
        """
        pass


if __name__ == '__main__':
    unittest.main()
