# coding: utf-8

"""
    Ringer Business API - User Management

    This API provides endpoints for managing users within a Ringer Business account. It allows for listing users, adding new users, retrieving details of a specific user, updating user information, and deleting users.  User management operations typically require authentication and administrative privileges. 

    The version of the OpenAPI document: 1.0.0
    Contact: support@ringer.tel
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from ringer_business.api.users_api import UsersApi


class TestUsersApi(unittest.TestCase):
    """UsersApi unit test stubs"""

    def setUp(self) -> None:
        self.api = UsersApi()

    def tearDown(self) -> None:
        pass

    def test_add_user(self) -> None:
        """Test case for add_user

        Add a New User
        """
        pass

    def test_delete_user_by_id(self) -> None:
        """Test case for delete_user_by_id

        Delete User
        """
        pass

    def test_get_user_by_id(self) -> None:
        """Test case for get_user_by_id

        Get User Details
        """
        pass

    def test_list_users(self) -> None:
        """Test case for list_users

        List Users
        """
        pass

    def test_update_user_by_id(self) -> None:
        """Test case for update_user_by_id

        Update User Information
        """
        pass


if __name__ == '__main__':
    unittest.main()
