# coding: utf-8

"""
    Ringer Business API - Template Management

    This API provides endpoints for managing service templates within a Ringer Business account. Templates offer a pre-configured set of resources (e.g., phone numbers, devices, voicemail) that can be quickly deployed for new users or seats, ensuring consistency and simplifying setup.  Functionality includes: - Listing available templates. - Creating a new template. - Retrieving details of a specific template. - Updating an existing template. - Deleting a template. - Cloning an existing template to create a new one. 

    The version of the OpenAPI document: 1.0.0
    Contact: support@ringer.tel
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from ringer_business.api.templates_api import TemplatesApi


class TestTemplatesApi(unittest.TestCase):
    """TemplatesApi unit test stubs"""

    def setUp(self) -> None:
        self.api = TemplatesApi()

    def tearDown(self) -> None:
        pass

    def test_clone_template_by_id(self) -> None:
        """Test case for clone_template_by_id

        Clone an Existing Template
        """
        pass

    def test_create_template(self) -> None:
        """Test case for create_template

        Create a New Template
        """
        pass

    def test_delete_template_by_id(self) -> None:
        """Test case for delete_template_by_id

        Delete a Template
        """
        pass

    def test_get_template_by_id(self) -> None:
        """Test case for get_template_by_id

        Get Template Details
        """
        pass

    def test_list_templates(self) -> None:
        """Test case for list_templates

        List Templates
        """
        pass

    def test_update_template_by_id(self) -> None:
        """Test case for update_template_by_id

        Update an Existing Template
        """
        pass


if __name__ == '__main__':
    unittest.main()
