# coding: utf-8

"""
    Ringer Business API - Call Records

    This API provides an endpoint for retrieving Call Detail Records (CDRs). Call records offer detailed information about calls made or received through the Ringer Business system, including source, destination, duration, cost, and timestamps.  Access to call records can be filtered by time range, paginated, sorted, and filtered by various call attributes. Permissions might vary; administrators may see all records for an organization, while individual users might only see their own. 

    The version of the OpenAPI document: 1.0.0
    Contact: support@ringer.tel
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictInt
from typing import Any, ClassVar, Dict, List, Optional
from ringer_business.models.call_record import CallRecord
from ringer_business.models.link import Link
from typing import Optional, Set
from typing_extensions import Self

class CallRecordListResponse(BaseModel):
    """
    A paginated list of call records.
    """ # noqa: E501
    call_records: List[CallRecord]
    total_items: Optional[StrictInt] = Field(default=None, description="Total number of records matching the query.")
    total_pages: Optional[StrictInt] = Field(default=None, description="Total number of pages based on page_size.")
    current_page: Optional[StrictInt] = Field(default=None, description="The current page number.")
    per_page: Optional[StrictInt] = Field(default=None, description="Number of records per page.")
    links: Optional[List[Link]] = None
    __properties: ClassVar[List[str]] = ["call_records", "total_items", "total_pages", "current_page", "per_page", "links"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of CallRecordListResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in call_records (list)
        _items = []
        if self.call_records:
            for _item_call_records in self.call_records:
                if _item_call_records:
                    _items.append(_item_call_records.to_dict())
            _dict['call_records'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in links (list)
        _items = []
        if self.links:
            for _item_links in self.links:
                if _item_links:
                    _items.append(_item_links.to_dict())
            _dict['links'] = _items
        # set to None if links (nullable) is None
        # and model_fields_set contains the field
        if self.links is None and "links" in self.model_fields_set:
            _dict['links'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of CallRecordListResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "call_records": [CallRecord.from_dict(_item) for _item in obj["call_records"]] if obj.get("call_records") is not None else None,
            "total_items": obj.get("total_items"),
            "total_pages": obj.get("total_pages"),
            "current_page": obj.get("current_page"),
            "per_page": obj.get("per_page"),
            "links": [Link.from_dict(_item) for _item in obj["links"]] if obj.get("links") is not None else None
        })
        return _obj


