# coding: utf-8

"""
    Ringer Business API - User Management

    This API provides endpoints for managing users within a Ringer Business account. It allows for listing users, adding new users, retrieving details of a specific user, updating user information, and deleting users.  User management operations typically require authentication and administrative privileges. 

    The version of the OpenAPI document: 1.0.0
    Contact: support@ringer.tel
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from ringer_business.models.user_create_request import UserCreateRequest

class TestUserCreateRequest(unittest.TestCase):
    """UserCreateRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> UserCreateRequest:
        """Test UserCreateRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `UserCreateRequest`
        """
        model = UserCreateRequest()
        if include_optional:
            return UserCreateRequest(
                first_name = 'Jane',
                last_name = 'Doe',
                email = 'jane.doe@example.com',
                role = 'user',
                active = True,
                locale = 'en-US'
            )
        else:
            return UserCreateRequest(
                first_name = 'Jane',
                last_name = 'Doe',
                email = 'jane.doe@example.com',
                role = 'user',
                active = True,
                locale = 'en-US',
        )
        """

    def testUserCreateRequest(self):
        """Test UserCreateRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
