# coding: utf-8

"""
    Ringer Business API

    This API provides comprehensive endpoints for the Ringer Business system. It includes functionality for managing customer accounts, addresses, sites,  phone numbers, payments, users, and other business resources.  Operations typically require authentication and appropriate permissions. 

    The version of the OpenAPI document: 1.0.4
    Contact: support@ringer.tel
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from ringer_business.api.confirmation_api import ConfirmationApi


class TestConfirmationApi(unittest.TestCase):
    """ConfirmationApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ConfirmationApi()

    def tearDown(self) -> None:
        pass

    def test_confirm_account(self) -> None:
        """Test case for confirm_account

        Confirm a User Account
        """
        pass


if __name__ == '__main__':
    unittest.main()
