# coding: utf-8

"""
    Ringer Business API - Template Management

    This API provides endpoints for managing service templates within a Ringer Business account. Templates offer a pre-configured set of resources (e.g., phone numbers, devices, voicemail) that can be quickly deployed for new users or seats, ensuring consistency and simplifying setup.  Functionality includes: - Listing available templates. - Creating a new template. - Retrieving details of a specific template. - Updating an existing template. - Deleting a template. - Cloning an existing template to create a new one. 

    The version of the OpenAPI document: 1.0.0
    Contact: support@ringer.tel
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from ringer_business.models.template_list_response import TemplateListResponse

class TestTemplateListResponse(unittest.TestCase):
    """TemplateListResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> TemplateListResponse:
        """Test TemplateListResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `TemplateListResponse`
        """
        model = TemplateListResponse()
        if include_optional:
            return TemplateListResponse(
                templates = [
                    {"id":1,"name":"Sales Team Standard Setup","features":{"switchable":"PhoneNumber","position":1,"attrs":[{"name":"name","derivative":"calculated","default":"Phone Number"}]},"last_updated_by":"jane.doe@example.com","owner":"Account ABC","links":[{"href":"/templates/1","rel":"self","method":"GET"}]}
                    ],
                total_items = 56,
                total_pages = 56,
                current_page = 1,
                per_page = 25,
                links = [
                    ringer_business.models.link.Link(
                        href = '', 
                        rel = '', 
                        title = '', 
                        method = 'GET', )
                    ]
            )
        else:
            return TemplateListResponse(
                templates = [
                    {"id":1,"name":"Sales Team Standard Setup","features":{"switchable":"PhoneNumber","position":1,"attrs":[{"name":"name","derivative":"calculated","default":"Phone Number"}]},"last_updated_by":"jane.doe@example.com","owner":"Account ABC","links":[{"href":"/templates/1","rel":"self","method":"GET"}]}
                    ],
                total_items = 56,
                total_pages = 56,
                current_page = 1,
                per_page = 25,
        )
        """

    def testTemplateListResponse(self):
        """Test TemplateListResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
