# coding: utf-8

"""
    Ringer Business API

    This API provides comprehensive endpoints for the Ringer Business system. It includes functionality for managing customer accounts, addresses, sites,  phone numbers, payments, users, and other business resources.  Operations typically require authentication and appropriate permissions. 

    The version of the OpenAPI document: 1.0.4
    Contact: support@ringer.tel
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from ringer_business.api.site_features_voicemail_boxes_api import SiteFeaturesVoicemailBoxesApi


class TestSiteFeaturesVoicemailBoxesApi(unittest.TestCase):
    """SiteFeaturesVoicemailBoxesApi unit test stubs"""

    def setUp(self) -> None:
        self.api = SiteFeaturesVoicemailBoxesApi()

    def tearDown(self) -> None:
        pass

    def test_create_site_voicemail_box(self) -> None:
        """Test case for create_site_voicemail_box

        Create Voicemail Box for a Site
        """
        pass

    def test_list_site_available_voicemail_boxes(self) -> None:
        """Test case for list_site_available_voicemail_boxes

        List Available Voicemail Boxes for a Site
        """
        pass

    def test_list_site_voicemail_boxes(self) -> None:
        """Test case for list_site_voicemail_boxes

        List Voicemail Boxes for a Site
        """
        pass


if __name__ == '__main__':
    unittest.main()
