# coding: utf-8

"""
    Ringer Business API

    This API provides comprehensive endpoints for the Ringer Business system. It includes functionality for managing customer accounts, addresses, sites,  phone numbers, payments, users, and other business resources.  Operations typically require authentication and appropriate permissions. 

    The version of the OpenAPI document: 1.0.4
    Contact: support@ringer.tel
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from ringer_business.api.site_features_sip_trunks_api import SiteFeaturesSIPTrunksApi


class TestSiteFeaturesSIPTrunksApi(unittest.TestCase):
    """SiteFeaturesSIPTrunksApi unit test stubs"""

    def setUp(self) -> None:
        self.api = SiteFeaturesSIPTrunksApi()

    def tearDown(self) -> None:
        pass

    def test_create_site_sip_trunk(self) -> None:
        """Test case for create_site_sip_trunk

        Create SIP Trunk for a Site
        """
        pass

    def test_delete_site_sip_trunk_by_id(self) -> None:
        """Test case for delete_site_sip_trunk_by_id

        Delete a SIP Trunk
        """
        pass

    def test_get_site_sip_trunk_by_id(self) -> None:
        """Test case for get_site_sip_trunk_by_id

        Get SIP Trunk Details
        """
        pass

    def test_list_site_sip_trunks(self) -> None:
        """Test case for list_site_sip_trunks

        List SIP Trunks for a Site
        """
        pass

    def test_regenerate_site_sip_trunk_password(self) -> None:
        """Test case for regenerate_site_sip_trunk_password

        Regenerate SIP Trunk Password
        """
        pass

    def test_transfer_sip_trunk(self) -> None:
        """Test case for transfer_sip_trunk

        Transfer SIP Trunk
        """
        pass

    def test_update_site_sip_trunk_by_id(self) -> None:
        """Test case for update_site_sip_trunk_by_id

        Update SIP Trunk
        """
        pass


if __name__ == '__main__':
    unittest.main()
