# coding: utf-8

"""
    Ringer Business API

    This API provides comprehensive endpoints for the Ringer Business system. It includes functionality for managing customer accounts, addresses, sites,  phone numbers, payments, users, and other business resources.  Operations typically require authentication and appropriate permissions. 

    The version of the OpenAPI document: 1.0.4
    Contact: support@ringer.tel
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from ringer_business.models.plan_core import PlanCore

class TestPlanCore(unittest.TestCase):
    """PlanCore unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PlanCore:
        """Test PlanCore
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PlanCore`
        """
        model = PlanCore()
        if include_optional:
            return PlanCore(
                id = 1,
                name = 'Standard Business Plan',
                description = 'Includes core calling features, 1000 domestic minutes, and basic voicemail.',
                total_cost = '49.99',
                currency = 'USD',
                removable = True,
                active = True,
                approved = True,
                finalized = True
            )
        else:
            return PlanCore(
                id = 1,
                name = 'Standard Business Plan',
                total_cost = '49.99',
                currency = 'USD',
                removable = True,
                active = True,
                approved = True,
                finalized = True,
        )
        """

    def testPlanCore(self):
        """Test PlanCore"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
