# coding: utf-8

"""
    Ringer Business API - Account Management

    This API provides endpoints for managing customer accounts in the Ringer Business system. It allows for retrieving account details, updating account information, managing account status (activation/closure), and updating associated addresses.  Account operations typically require authentication and appropriate permissions (e.g., administrator role for certain updates). 

    The version of the OpenAPI document: 1.0.0
    Contact: support@ringer.tel
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from setuptools import setup, find_packages  # noqa: H301

# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools
NAME = "ringer-business"
VERSION = "1.0.0"
PYTHON_REQUIRES = ">= 3.9"
REQUIRES = [
    "urllib3 >= 2.1.0, < 3.0.0",
    "python-dateutil >= 2.8.2",
    "pydantic >= 2",
    "typing-extensions >= 4.7.1",
]

setup(
    name='ringer_ivy',
    version='1.0.4',
    description="Ringer Business API - Account Management",
    author="Ringer API Support",
    author_email="support@ringer.tel",
    url="",
    keywords=["OpenAPI", "OpenAPI-Generator", "Ringer Business API - Account Management"],
    install_requires=REQUIRES,
    packages=find_packages(exclude=["test", "tests"]),
    include_package_data=True,
    license="MIT License",
    long_description_content_type='text/markdown',
    long_description="""\
    This API provides endpoints for managing customer accounts in the Ringer Business system. It allows for retrieving account details, updating account information, managing account status (activation/closure), and updating associated addresses.  Account operations typically require authentication and appropriate permissions (e.g., administrator role for certain updates). 
    """,  # noqa: E501
    package_data={"ringer_business": ["py.typed"]},
)