# coding: utf-8

"""
    Ringer Business API - Sign Up

    This API provides the endpoint for new customers to sign up for the Ringer Business service. Successful sign-up creates a new customer account and provides a confirmation token that is typically used in a subsequent step to activate the account (see Confirmation API). 

    The version of the OpenAPI document: 1.0.0
    Contact: support@ringer.tel
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from ringer_business.api.sign_up_api import SignUpApi


class TestSignUpApi(unittest.TestCase):
    """SignUpApi unit test stubs"""

    def setUp(self) -> None:
        self.api = SignUpApi()

    def tearDown(self) -> None:
        pass

    def test_sign_up_customer(self) -> None:
        """Test case for sign_up_customer

        Register a new Customer Account
        """
        pass


if __name__ == '__main__':
    unittest.main()
