# coding: utf-8

"""
    Ringer Business API - Sign Up

    This API provides the endpoint for new customers to sign up for the Ringer Business service. Successful sign-up creates a new customer account and provides a confirmation token that is typically used in a subsequent step to activate the account (see Confirmation API). 

    The version of the OpenAPI document: 1.0.0
    Contact: support@ringer.tel
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from ringer_business.models.address_registered import AddressRegistered

class TestAddressRegistered(unittest.TestCase):
    """AddressRegistered unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> AddressRegistered:
        """Test AddressRegistered
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `AddressRegistered`
        """
        model = AddressRegistered()
        if include_optional:
            return AddressRegistered(
                email = 'contact@exampleinnovations.com',
                street_address = '123 Innovation Drive, Suite 400',
                country = 'US',
                city = 'Techville',
                state_province = 'CA',
                postal_code = '90210',
                contact_number = '+18005551212',
                id = 672
            )
        else:
            return AddressRegistered(
                email = 'contact@exampleinnovations.com',
                street_address = '123 Innovation Drive, Suite 400',
                country = 'US',
                city = 'Techville',
                postal_code = '90210',
                contact_number = '+18005551212',
                id = 672,
        )
        """

    def testAddressRegistered(self):
        """Test AddressRegistered"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
