# coding: utf-8

"""
    Ringer Business API - Statements

    This API provides endpoints for accessing account statements (receipts). Statements are typically generated at the end of a service interval and provide a summary of charges and payments. Developers can use this API to retrieve a list of statements or the details of a specific statement. 

    The version of the OpenAPI document: 1.0.0
    Contact: support@ringer.tel
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from ringer_business.api.statements_api import StatementsApi


class TestStatementsApi(unittest.TestCase):
    """StatementsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = StatementsApi()

    def tearDown(self) -> None:
        pass

    def test_get_statement_by_id(self) -> None:
        """Test case for get_statement_by_id

        Get Statement Details
        """
        pass

    def test_list_statements(self) -> None:
        """Test case for list_statements

        List Account Statements
        """
        pass


if __name__ == '__main__':
    unittest.main()
