# coding: utf-8

"""
    Ringer Business API - Sign Up

    This API provides the endpoint for new customers to sign up for the Ringer Business service. Successful sign-up creates a new customer account and provides a confirmation token that is typically used in a subsequent step to activate the account (see Confirmation API). 

    The version of the OpenAPI document: 1.0.0
    Contact: support@ringer.tel
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from ringer_business.models.customer_registration_request import CustomerRegistrationRequest

class TestCustomerRegistrationRequest(unittest.TestCase):
    """CustomerRegistrationRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> CustomerRegistrationRequest:
        """Test CustomerRegistrationRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `CustomerRegistrationRequest`
        """
        model = CustomerRegistrationRequest()
        if include_optional:
            return CustomerRegistrationRequest(
                name = 'Example Innovations Inc.',
                address = {"email":"newuser@domain.com","street_address":"789 Startup Street","country":"US","city":"Anytown","state_province":"NY","postal_code":"10001","contact_number":"+12125550100"}
            )
        else:
            return CustomerRegistrationRequest(
                name = 'Example Innovations Inc.',
                address = {"email":"newuser@domain.com","street_address":"789 Startup Street","country":"US","city":"Anytown","state_province":"NY","postal_code":"10001","contact_number":"+12125550100"},
        )
        """

    def testCustomerRegistrationRequest(self):
        """Test CustomerRegistrationRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
