# coding: utf-8

"""
    Ringer Business API - Password Management

    This API provides endpoints for password management, including: - Requesting a password reset (forgot password). - Resetting the password using a token.  These operations help users regain access to their accounts if they have forgotten their password. 

    The version of the OpenAPI document: 1.0.0
    Contact: support@ringer.tel
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from ringer_business.models.forgot_password_response import ForgotPasswordResponse

class TestForgotPasswordResponse(unittest.TestCase):
    """ForgotPasswordResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ForgotPasswordResponse:
        """Test ForgotPasswordResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ForgotPasswordResponse`
        """
        model = ForgotPasswordResponse()
        if include_optional:
            return ForgotPasswordResponse(
                message = 'If an account with that email exists, a password reset link has been sent.'
            )
        else:
            return ForgotPasswordResponse(
                message = 'If an account with that email exists, a password reset link has been sent.',
        )
        """

    def testForgotPasswordResponse(self):
        """Test ForgotPasswordResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
