# coding: utf-8

"""
    Ringer Business API

    This API provides comprehensive endpoints for the Ringer Business system. It includes functionality for managing customer accounts, addresses, sites,  phone numbers, payments, users, and other business resources.  Operations typically require authentication and appropriate permissions. 

    The version of the OpenAPI document: 1.0.4
    Contact: support@ringer.tel
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from ringer_business.api.payments_api import PaymentsApi


class TestPaymentsApi(unittest.TestCase):
    """PaymentsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = PaymentsApi()

    def tearDown(self) -> None:
        pass

    def test_create_payment(self) -> None:
        """Test case for create_payment

        Create a Payment
        """
        pass

    def test_list_payments(self) -> None:
        """Test case for list_payments

        List Payments
        """
        pass


if __name__ == '__main__':
    unittest.main()
