# coding: utf-8

"""
    Ringer Business API

    This API provides comprehensive endpoints for the Ringer Business system. It includes functionality for managing customer accounts, addresses, sites,  phone numbers, payments, users, and other business resources.  Operations typically require authentication and appropriate permissions. 

    The version of the OpenAPI document: 1.0.4
    Contact: support@ringer.tel
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from ringer_business.api.site_features_call_blocking_api import SiteFeaturesCallBlockingApi


class TestSiteFeaturesCallBlockingApi(unittest.TestCase):
    """SiteFeaturesCallBlockingApi unit test stubs"""

    def setUp(self) -> None:
        self.api = SiteFeaturesCallBlockingApi()

    def tearDown(self) -> None:
        pass

    def test_create_site_call_block(self) -> None:
        """Test case for create_site_call_block

        Create a Call Block Rule
        """
        pass

    def test_delete_site_call_block_by_id(self) -> None:
        """Test case for delete_site_call_block_by_id

        Delete a Call Block Rule
        """
        pass

    def test_get_site_call_block_by_id(self) -> None:
        """Test case for get_site_call_block_by_id

        Get Call Block Rule Details
        """
        pass

    def test_list_site_call_blocks(self) -> None:
        """Test case for list_site_call_blocks

        List Call Block Rules for a Site
        """
        pass

    def test_update_site_call_block_by_id(self) -> None:
        """Test case for update_site_call_block_by_id

        Update Call Block Rule
        """
        pass


if __name__ == '__main__':
    unittest.main()
