# coding: utf-8

"""
    Ringer Business API - Password Management

    This API provides endpoints for password management, including: - Requesting a password reset (forgot password). - Resetting the password using a token.  These operations help users regain access to their accounts if they have forgotten their password. 

    The version of the OpenAPI document: 1.0.0
    Contact: support@ringer.tel
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from ringer_business.api.password_management_api import PasswordManagementApi


class TestPasswordManagementApi(unittest.TestCase):
    """PasswordManagementApi unit test stubs"""

    def setUp(self) -> None:
        self.api = PasswordManagementApi()

    def tearDown(self) -> None:
        pass

    def test_request_password_reset(self) -> None:
        """Test case for request_password_reset

        Request Password Reset
        """
        pass

    def test_reset_password(self) -> None:
        """Test case for reset_password

        Reset Password
        """
        pass


if __name__ == '__main__':
    unittest.main()
